@@ -4,9 +4,21 @@
 
 set -uex
 
+# provided lacks some development packages
+yum install -y expat-devel
+
+case $(uname -m) in
+  "x86_64")
+    ARCH=x86_64;;
+  "aarch64")
+    ARCH=arm64;;
+  *)
+    echo "unknown architecture: $(uname -m)"
+esac
+
 TAG=$1
 cd /opt
-unzip "/var/task/.perl-layer/dist/perl-$TAG-runtime.zip"
+unzip "/var/task/.perl-layer/dist/perl-$TAG-runtime-$ARCH.zip"
 /opt/bin/cpanm --notest --no-man-pages Paws@0.44
 
 # install perlstrip
